==> docfbe_2_3_42_72.zip: docfbe_2_3_42_72/source/TCFbERowColumnCachedTable.cpp <==
/*
    TCFbERowColumnCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbERowColumnCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbERowColumnCachedTable::TCFbERowColumnCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// w肳ꂽse[u쐬
__fastcall TCFbERowColumnCachedTable::TCFbERowColumnCachedTable(TStringList* RowLabelList, TStringList* ColumnLabelList)
    : TCFbECachedTable(RowLabelList, ColumnLabelList)
{
}

//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbERowColumnCachedTable::TCFbERowColumnCachedTable(TStringList* SourceCsvStringList)
    : TCFbECachedTable(SourceCsvStringList)
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbERowColumnCachedTable::~TCFbERowColumnCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbERowColumnCachedTable::ParentAddRow(const char* RowLabel)
{
    return this->AddRow(RowLabel);
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbERowColumnCachedTable::ParentAddColumn(const char* ColumnLabel)
{
    return this->AddColumn(ColumnLabel);
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbERowColumnCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    this->DeleteRowByIndex(TargetRowIndex);
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbERowColumnCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    this->DeleteColumnByIndex(TargetColumnIndex);
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbERowColumnCachedTable::CreateClone(void)
{
    TCFbERowColumnCachedTable* Clone = new TCFbERowColumnCachedTable();
    Clone->Assign(this);
    return Clone;
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbERowColumnCachedTable::CreateRotatedClone(void)
{
    TCFbERowColumnCachedTable* Clone = new TCFbERowColumnCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------

==> docfbe_2_4_47_83.zip: docfbe_2_4_47_83/source/TCFbERowColumnCachedTable.cpp <==
/*
    TCFbERowColumnCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbERowColumnCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbERowColumnCachedTable::TCFbERowColumnCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// w肳ꂽse[u쐬
__fastcall TCFbERowColumnCachedTable::TCFbERowColumnCachedTable(TStringList* RowLabelList, TStringList* ColumnLabelList)
    : TCFbECachedTable(RowLabelList, ColumnLabelList)
{
}

//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbERowColumnCachedTable::TCFbERowColumnCachedTable(TStringList* SourceCsvStringList, AnsiString IsQualitativeIndicator)
    : TCFbECachedTable(SourceCsvStringList, IsQualitativeIndicator)
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbERowColumnCachedTable::~TCFbERowColumnCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbERowColumnCachedTable::ParentAddRow(const char* RowLabel, const bool IsQualitative)
{
    return this->AddRow(RowLabel, IsQualitative);
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbERowColumnCachedTable::ParentAddColumn(const char* ColumnLabel, const bool IsQualitative)
{
    return this->AddColumn(ColumnLabel, IsQualitative);
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbERowColumnCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    this->DeleteRowByIndex(TargetRowIndex);
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbERowColumnCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    this->DeleteColumnByIndex(TargetColumnIndex);
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbERowColumnCachedTable::CreateClone(void)
{
    TCFbERowColumnCachedTable* Clone = new TCFbERowColumnCachedTable();
    Clone->Assign(this);
    return Clone;
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbERowColumnCachedTable::CreateRotatedClone(void)
{
    TCFbERowColumnCachedTable* Clone = new TCFbERowColumnCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------
